..
    Copyright (C) 2024 CERN.

    Invenio-Preservation-Sync is free software; you can redistribute it
    and/or modify it under the terms of the MIT License; see LICENSE file for
    more details.

Authors
=======

Invenio module that adds preservation sync integration to the platform.

- Panna Georgina Liptak <panna.georgina.liptak@cern.ch>
